@@ -211,9 +211,12 @@ class Log(InterfaceView):
             line = {
                 "revision": self.revision_items[row].revision,
                 "author": self.revision_items[row].author,
-                "message": self.revision_items[row].message,
-                "parents": self.revision_items[row].parents
+                "message": self.revision_items[row].message
             }
+
+            if self.revision_items[row].parents:
+                line["parents"] = self.revision_items[row].parents
+
             try:
                 line["next_revision"] = self.revision_items[row+1].revision
             except IndexError,e:
@@ -450,7 +453,7 @@ class SVNLog(Log):
             self.svn.log, 
             self.path,
             revision_start=start,
-            limit=self.limit+1,
+            limit=self.limit,
             discover_changed_paths=True
         )
         self.action.append(self.refresh)
@@ -531,7 +534,7 @@ class SVNLog(Log):
                     
     def on_next_clicked(self, widget):
         self.previous_starts.append(self.rev_start)
-        self.rev_start = self.rev_end - 1
+        self.rev_start = int(self.rev_end) - 1
 
         if self.rev_start < 1:
             self.rev_start = 1
@@ -944,6 +947,16 @@ class LogTopContextMenuCallbacks:
         self.revisions = revisions
 
         self.vcs_name = self.caller.get_vcs_name()
+
+    def find_parent(self, revision):
+        if ("parents" in revision) and len(revision["parents"]) > 0:
+            parent = unicode(revision["parents"][0])
+        elif ("next_revision" in revision):
+            parent = unicode(revision["next_revision"])
+        else:
+            parent = unicode(int(unicode(revision["revision"])) - 1)
+
+        return parent
         
     def view_diff_working_copy(self, widget, data=None):
         rabbitvcs.util.helper.launch_ui_window("diff", [
@@ -952,10 +965,7 @@ class LogTopContextMenuCallbacks:
         ])
 
     def view_diff_previous_revision(self, widget, data=None):
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "%s@%s" % (self.path, parent),
@@ -987,10 +997,7 @@ class LogTopContextMenuCallbacks:
         ])
 
     def compare_previous_revision(self, widget, data=None):
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         rabbitvcs.util.helper.launch_ui_window("diff", [
             "-s",
@@ -1013,10 +1020,7 @@ class LogTopContextMenuCallbacks:
 
     def show_changes_previous_revision(self, widget, data=None):
         rev_first = unicode(self.revisions[0]["revision"])
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
         
         path = self.path
         if self.vcs_name == rabbitvcs.vcs.VCS_SVN:
@@ -1024,7 +1028,7 @@ class LogTopContextMenuCallbacks:
 
         rabbitvcs.util.helper.launch_ui_window("changes", [
             "%s@%s" % (path, parent),
-            "%s@%s" % (path, unicode(rev_last)),
+            "%s@%s" % (path, unicode(rev_first)),
             "--vcs=%s" % self.caller.get_vcs_name()
         ])
 
@@ -1270,13 +1274,20 @@ class LogBottomContextMenuCallbacks:
         self.paths = paths
         self.revisions = revisions
 
+    def find_parent(self, revision):
+        if ("parents" in revision) and len(revision["parents"]) > 0:
+            parent = unicode(revision["parents"][0])
+        elif ("next_revision" in revision):
+            parent = unicode(revision["next_revision"])
+        else:
+            parent = unicode(int(unicode(revision["revision"])) - 1)
+
+        return parent
+
     def view_diff_previous_revision(self, widget, data=None):
         rev = unicode(self.revisions[0]["revision"])
 
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         path_item = self.paths[0]
         url = self.caller.root_url + path_item
@@ -1293,10 +1304,7 @@ class LogBottomContextMenuCallbacks:
     def compare_previous_revision(self, widget, data=None):
         rev = unicode(self.revisions[0]["revision"])
         
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
             
         path_item = self.paths[0]
         url = self.caller.root_url + path_item
@@ -1315,10 +1323,7 @@ class LogBottomContextMenuCallbacks:
     def show_changes_previous_revision(self, widget, data=None):
         rev_first = unicode(self.revisions[0]["revision"])
         
-        if len(self.revisions[0]["parents"]) > 0:
-            parent = unicode(self.revisions[0]["parents"][0])
-        else:
-            parent = unicode(self.revisions[0]["next_revision"])
+        parent = self.find_parent(self.revisions[0])
 
         url = self.paths[0]
         if self.vcs_name == rabbitvcs.vcs.VCS_SVN:
